import aoc_helper
from aoc_helper import (
    Grid,
    PrioQueue,
    decode_text,
    extract_ints,
    frange,
    irange,
    iter,
    list,
    map,
    range,
    tail_call,
)

raw = aoc_helper.fetch({day}, {year})


def parse_raw():
    ...


data = parse_raw()


def part_one():
    ...


def part_two():
    ...


aoc_helper.lazy_submit(day={day}, year={year}, solution=part_one)
aoc_helper.lazy_submit(day={day}, year={year}, solution=part_two)
